

::: fhir_kindling.fhir_server.fhir_server.FhirServer
    handler: python
    rendering:
      members: True
      show_source: False
      heading_level: 2
      show_root_heading: True
      show_if_no_docstring: True
      show_root_full_path: False
      members_order: source

::: fhir_kindling.fhir_query.FHIRQuery
    handler: python
    rendering:
      members: True
      show_source: False
      heading_level: 2
      show_root_heading: True
      show_if_no_docstring: True
      show_root_full_path: False
      members_order: source

::: fhir_kindling.fhir_query.QueryResponse
    handler: python
    rendering:
      members: True
      show_source: False
      heading_level: 2
      show_root_heading: True
      show_if_no_docstring: True
      show_root_full_path: False
      members_order: source
